/** 
	Olimexino328 + MOD-MP3-X Example
	Plays a song from the root folder of the miniSD card
	
	See the README for the commands related to files/folders and 
	the MOD-MP3
	
	This example was written and tested on Arduino 1.0.1
	
	Your Olimexino328 board shoud be connected to a power source
	different from USB because, if present, the USB connection
	takes up the D0 and D1 pins needed for the serial communication
	via UEXT.
	
	You should make sure the jumpers on the MOD-MP3 
	are in the following positions:
		
	|-----Jumper---|||---Position------|
	|----------------------------------|
	| UEXT/BAT 		:	BAT (if powered from external source)
	|		 		:	UEXT(if powered from the UEXT)
	| BOOT_E		:	OPEN		   |
	| SA_E			:	OPEN		   |
	| DREQ			:	OPEN		   |
	| MP3 RST/TXD	:	TXD			   |
	| DREQ/RXD 		:	RXD			   |
	| VHS_RST  		:	OPEN		   |
	| STM_RST  		:	OPEN		   |
	|----------------------------------|
	
	For other useful info, refer to the README in the project dir.
	
	If you have any questions, email
	support@olimex.com
	
	OLIMEX, July 2012
	https://www.olimex.com/dev
	
**/

//Defs specific to the Olimexino-328 board
#define BBIT (PIND & B00000100)!=0			// Used to check if button has been pressed
#define BUTTONINPUT DDRD &= B11111011		// Init the Button
#define YLED 9 
#define GLED 13
void blinkyellow(void);							// blink 5 times
void blinkgreen(void); 							// blink 5 times

// Defs for the MOD-MP3
#define mp3_baud 9600

/**************************************************/
/** Code that waits for the user to press the button
**/	
	void wait_ch(){ 
		delay(500);
		while( BBIT ){}
		delay(300);	
		}
	
	#define WAIT wait_ch()
/**************************************************/

void setup(){
	
	BUTTONINPUT;
	Serial.begin(mp3_baud);	

	// Wait for some time to make sure the MOD-MP3 has been
	// initialised properly
	delay(2000);
	
	WAIT; 		// Press the button to continue...
	
}

void loop(){
	
	// Send the command to play the first mp3 file in the root dir
	// Refer to the README file on how to change the current dir
	// Note: Using filenames with the PSONGNAME command will work easily
	//       only with filenames <= 8 characters -> like ABCDEFGH.MP3 (8.3 filename)
	//		 Names with more characters get shortened according to 8.3 rules
	//		 More info on 8.3 names: http://en.wikipedia.org/wiki/8.3_filename

	Serial.print("pnum 0\r\n"); //Send your command
								//(!)Don't forget the "\r\n\" at the end
	
	WAIT;						//Wait for button
	
	Serial.print("C\r\n");		//Send the command to stop playing
	
	WAIT;						//Wait for button
	
}

void blinkyellow(){
	pinMode(YLED, OUTPUT);
	for(int i=0; i<10; i++)
	{
		digitalWrite(YLED, digitalRead(YLED)^1);
		delay(300);
	}	
}

void blinkgreen(){
	pinMode(GLED, OUTPUT);
	for(int i=0; i<10; i++)
	{
		digitalWrite(GLED, digitalRead(GLED)^1);
		delay(300);
	}	
}